@@ -2,11 +2,26 @@
 
 # Add any Sphinx extension module names here, as strings. They can be
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
-extensions = ['sphinx.ext.autodoc',
+extensions = ['sphinxcontrib.apidoc',
               'sphinx.ext.viewcode',
-              'oslosphinx',
+              'openstackdocstheme',
+              'cliff.sphinxext',
               ]
 
+# sphinxcontrib.apidoc options
+apidoc_module_dir = '../../ironicclient'
+apidoc_output_dir = 'reference/api'
+apidoc_excluded_paths = [
+    'tests/functional/*',
+    'tests']
+apidoc_separate_modules = True
+
+
+# openstackdocstheme options
+openstackdocs_repo_name = 'openstack/python-ironicclient'
+openstackdocs_pdf_link = True
+openstackdocs_use_storyboard = True
+
 # autodoc generation is a bit aggressive and a nuisance when doing heavy
 # text edit cycles.
 # execute "export SPHINX_DEBUG=1" in your terminal to disable
@@ -21,7 +36,6 @@ source_suffix = '.rst'
 master_doc = 'index'
 
 # General information about the project.
-project = u'python-ironicclient'
 copyright = u'OpenStack Foundation'
 
 # A list of ignored prefixes for module index sorting.
@@ -35,7 +49,7 @@ add_function_parentheses = True
 add_module_names = True
 
 # The name of the Pygments (syntax highlighting) style to use.
-pygments_style = 'sphinx'
+pygments_style = 'native'
 
 # A list of glob-style patterns that should be excluded when looking for
 # source files. They are matched against the source file names relative to the
@@ -49,10 +63,12 @@ exclude_patterns = ['api/ironicclient.tests.functional.*']
 #html_theme_path = ["."]
 #html_theme = '_theme'
 #html_static_path = ['_static']
+html_theme = 'openstackdocs'
 
 # Output file base name for HTML help builder.
-htmlhelp_basename = '%sdoc' % project
+htmlhelp_basename = 'python-ironicclientdoc'
 
+latex_use_xindy = False
 
 # Grouping the document tree into LaTeX files. List of tuples
 # (source start file, target name, title, author, documentclass
@@ -60,9 +76,11 @@ htmlhelp_basename = '%sdoc' % project
 latex_documents = [
     (
         'index',
-        '%s.tex' % project,
-        u'%s Documentation' % project,
+        'doc-python-ironicclient.tex',
+        u'Python Ironic Client Documentation',
         u'OpenStack LLC',
         'manual'
     ),
 ]
+
+autoprogram_cliff_application = 'openstack'
