@@ -13,9 +13,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from __future__ import print_function
-
 import argparse
+import base64
 import contextlib
 import gzip
 import json
@@ -24,10 +23,9 @@ import shutil
 import subprocess
 import sys
 import tempfile
+import time
 
-from oslo_serialization import base64
 from oslo_utils import strutils
-import six
 
 from ironicclient.common.i18n import _
 from ironicclient import exc
@@ -162,7 +160,7 @@ def convert_list_props_to_comma_separated(data, props=None):
     for prop in props:
         val = data.get(prop, None)
         if isinstance(val, list):
-            result[prop] = ', '.join(map(six.text_type, val))
+            result[prop] = ', '.join(map(str, val))
 
     return result
 
@@ -296,7 +294,7 @@ def make_configdrive(path):
                 shutil.copyfileobj(tmpfile, gz_file)
 
             tmpzipfile.seek(0)
-            return base64.encode_as_bytes(tmpzipfile.read())
+            return base64.b64encode(tmpzipfile.read())
 
 
 def check_empty_arg(arg, arg_descriptor):
@@ -390,3 +388,39 @@ def handle_json_or_file_arg(json_arg):
         raise exc.InvalidAttribute(err)
 
     return json_arg
+
+
+def poll(timeout, poll_interval, poll_delay_function, timeout_message):
+    if not isinstance(timeout, (int, float)) or timeout < 0:
+        raise ValueError(_('Timeout must be a non-negative number'))
+
+    threshold = time.time() + timeout
+    poll_delay_function = (time.sleep if poll_delay_function is None
+                           else poll_delay_function)
+    if not callable(poll_delay_function):
+        raise TypeError(_('poll_delay_function must be callable'))
+
+    count = 0
+    while not timeout or time.time() < threshold:
+        yield count
+
+        poll_delay_function(poll_interval)
+        count += 1
+
+    raise exc.StateTransitionTimeout(timeout_message)
+
+
+def handle_json_arg(json_arg, info_desc):
+    """Read a JSON argument from stdin, file or string.
+
+    :param json_arg: May be a file name containing the JSON, a JSON string, or
+        '-' indicating that the argument should be read from standard input.
+    :param info_desc: A string description of the desired information
+    :returns: A list or dictionary parsed from JSON.
+    :raises: InvalidAttribute if the argument cannot be parsed.
+    """
+    if json_arg == '-':
+        json_arg = get_from_stdin(info_desc)
+    if json_arg:
+        json_arg = handle_json_or_file_arg(json_arg)
+    return json_arg
