@@ -15,8 +15,8 @@
 #
 
 import copy
+from unittest import mock
 
-import mock
 from osc_lib.tests import utils as osctestutils
 from osc_lib import utils as oscutils
 
@@ -66,7 +66,7 @@ class TestCreateBaremetalPort(TestBaremetalPort):
         # Set expected values
         args = {
             'address': baremetal_fakes.baremetal_port_address,
-            'node_uuid': baremetal_fakes.baremetal_uuid,
+            'node_uuid': baremetal_fakes.baremetal_uuid
         }
 
         self.baremetal_mock.port.create.assert_called_once_with(**args)
@@ -249,11 +249,29 @@ class TestCreateBaremetalPort(TestBaremetalPort):
         args = {
             'address': baremetal_fakes.baremetal_port_address,
             'node_uuid': baremetal_fakes.baremetal_uuid,
-            'physical_network': baremetal_fakes.baremetal_port_physical_network
+            'physical_network':
+                baremetal_fakes.baremetal_port_physical_network
         }
 
         self.baremetal_mock.port.create.assert_called_once_with(**args)
 
+    def test_baremetal_port_create_smartnic(self):
+        arglist = [
+            baremetal_fakes.baremetal_port_address,
+            '--node', baremetal_fakes.baremetal_uuid,
+            '--is-smartnic']
+        verifylist = [
+            ('node_uuid', baremetal_fakes.baremetal_uuid),
+            ('address', baremetal_fakes.baremetal_port_address),
+            ('is_smartnic', True)]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        self.cmd.take_action(parsed_args)
+        args = {
+            'address': baremetal_fakes.baremetal_port_address,
+            'node_uuid': baremetal_fakes.baremetal_uuid,
+            'is_smartnic': True}
+        self.baremetal_mock.port.create.assert_called_once_with(**args)
+
 
 class TestShowBaremetalPort(TestBaremetalPort):
     def setUp(self):
@@ -397,6 +415,18 @@ class TestBaremetalPortUnset(TestBaremetalPort):
             'port',
             [{'path': '/physical_network', 'op': 'remove'}])
 
+    def test_baremetal_port_unset_is_smartnic(self):
+        arglist = ['port', '--is-smartnic']
+        verifylist = [('port', 'port'),
+                      ('is_smartnic', True)]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        self.cmd.take_action(parsed_args)
+        self.baremetal_mock.port.update.assert_called_once_with(
+            'port',
+            [{'path': '/is_smartnic', 'op': 'add', 'value': 'False'}])
+
 
 class TestBaremetalPortSet(TestBaremetalPort):
     def setUp(self):
@@ -549,6 +579,22 @@ class TestBaremetalPortSet(TestBaremetalPort):
         self.cmd.take_action(parsed_args)
         self.assertFalse(self.baremetal_mock.port.update.called)
 
+    def test_baremetal_port_set_is_smartnic(self):
+        arglist = [
+            baremetal_fakes.baremetal_port_uuid,
+            '--is-smartnic']
+        verifylist = [
+            ('port', baremetal_fakes.baremetal_port_uuid),
+            ('is_smartnic', True)]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        self.cmd.take_action(parsed_args)
+        self.baremetal_mock.port.update.assert_called_once_with(
+            baremetal_fakes.baremetal_port_uuid,
+            [{'path': '/is_smartnic', 'value': 'True',
+              'op': 'add'}])
+
 
 class TestBaremetalPortDelete(TestBaremetalPort):
     def setUp(self):
@@ -580,7 +626,7 @@ class TestBaremetalPortDelete(TestBaremetalPort):
         self.cmd.take_action(parsed_args)
 
         args = ['zzz-zzzzzz-zzzz', 'fakename']
-        self.baremetal_mock.port.delete.has_calls(
+        self.baremetal_mock.port.delete.assert_has_calls(
             [mock.call(x) for x in args])
         self.assertEqual(2, self.baremetal_mock.port.delete.call_count)
 
@@ -595,7 +641,7 @@ class TestBaremetalPortDelete(TestBaremetalPort):
                           parsed_args)
 
         args = ['zzz-zzzzzz-zzzz', 'badname']
-        self.baremetal_mock.port.delete.has_calls(
+        self.baremetal_mock.port.delete.assert_has_calls(
             [mock.call(x) for x in args])
         self.assertEqual(2, self.baremetal_mock.port.delete.call_count)
 
@@ -704,7 +750,7 @@ class TestBaremetalPortList(TestBaremetalPort):
         collist = ('UUID', 'Address', 'Created At', 'Extra', 'Node UUID',
                    'Local Link Connection', 'Portgroup UUID',
                    'PXE boot enabled', 'Physical Network', 'Updated At',
-                   'Internal Info')
+                   'Internal Info', 'Is Smart NIC port')
         self.assertEqual(collist, columns)
 
         datalist = ((
@@ -718,6 +764,7 @@ class TestBaremetalPortList(TestBaremetalPort):
             '',
             '',
             '',
+            '',
             ''
         ), )
         self.assertEqual(datalist, tuple(data))
